==> weather-0.1-src.tar.gz: weather-0.1/src/java/jp/sf/pal/weather/Weather.java <==
/*
 * Copyright 2005-2006 The Portal Application Laboratory Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * Weather class
 */
package jp.sf.pal.weather ;

public class Weather {
	
	private String	area ;
	private String	pref ;
	private String	city ;
	private String	title ;
	private String	link ;
	private String	forecastday ;
	private String	day ;
	private String	forecastdate ;
	private String	publictime ;
	private String	telop ;
	private String	description ;
	private String	imgTitle ;
	private String	imgLink ;
	private String	imgUrl ;
	private String	imgWidth ;
	private String	imgHeight ;
	private String	tempMax ;
	private String	tempMin ;
	private String	copyrightTitle ;
	private String	copyrightLink ;
	private String	copyrightImageTitle ;
	private String	copyrightImageUrl ;
	private String	copyrightImageLink ;
    
    public String getArea() {
        return area;
    }
    public void setArea(String area) {
        this.area = area;
    }
    public String getCity() {
        return city;
    }
    public void setCity(String city) {
        this.city = city;
    }
    public String getCopyrightImageLink() {
        return copyrightImageLink;
    }
    public void setCopyrightImageLink(String copyrightImageLink) {
        this.copyrightImageLink = copyrightImageLink;
    }
    public String getCopyrightImageTitle() {
        return copyrightImageTitle;
    }
    public void setCopyrightImageTitle(String copyrightImageTitle) {
        this.copyrightImageTitle = copyrightImageTitle;
    }
    public String getCopyrightImageUrl() {
        return copyrightImageUrl;
    }
    public void setCopyrightImageUrl(String copyrightImageUrl) {
        this.copyrightImageUrl = copyrightImageUrl;
    }
    public String getCopyrightLink() {
        return copyrightLink;
    }
    public void setCopyrightLink(String copyrightLink) {
        this.copyrightLink = copyrightLink;
    }
    public String getCopyrightTitle() {
        return copyrightTitle;
    }
    public void setCopyrightTitle(String copyrightTitle) {
        this.copyrightTitle = copyrightTitle;
    }
    public String getDay() {
        return day;
    }
    public void setDay(String day) {
        this.day = day;
    }
    public String getDescription() {
        return description;
    }
    public void setDescription(String description) {
        this.description = description;
    }
    public String getForecastdate() {
        return forecastdate;
    }
    public void setForecastdate(String forecastdate) {
        this.forecastdate = forecastdate;
    }
    public String getForecastday() {
        return forecastday;
    }
    public void setForecastday(String forecastday) {
        this.forecastday = forecastday;
    }
    public String getImgHeight() {
        return imgHeight;
    }
    public void setImgHeight(String imgHeight) {
        this.imgHeight = imgHeight;
    }
    public String getImgLink() {
        return imgLink;
    }
    public void setImgLink(String imgLink) {
        this.imgLink = imgLink;
    }
    public String getImgTitle() {
        return imgTitle;
    }
    public void setImgTitle(String imgTitle) {
        this.imgTitle = imgTitle;
    }
    public String getImgUrl() {
        return imgUrl;
    }
    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }
    public String getImgWidth() {
        return imgWidth;
    }
    public void setImgWidth(String imgWidth) {
        this.imgWidth = imgWidth;
    }
    public String getLink() {
        return link;
    }
    public void setLink(String link) {
        this.link = link;
    }
    public String getPref() {
        return pref;
    }
    public void setPref(String pref) {
        this.pref = pref;
    }
    public String getPublictime() {
        return publictime;
    }
    public void setPublictime(String publictime) {
        this.publictime = publictime;
    }
    public String getTelop() {
        return telop;
    }
    public void setTelop(String telop) {
        this.telop = telop;
    }
    public String getTempMax() {
        return tempMax;
    }
    public void setTempMax(String tempMax) {
        this.tempMax = tempMax;
    }
    public String getTempMin() {
        return tempMin;
    }
    public void setTempMin(String tempMin) {
        this.tempMin = tempMin;
    }
    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }
	
}

==> weather-0.3-src.tar.gz: weather-0.3/src/java/jp/sf/pal/weather/Weather.java <==
/*
 * Copyright 2005-2006 The Portal Application Laboratory Team.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * Weather class
 */
package jp.sf.pal.weather ;

public class Weather {
	
	private String	area ;
	private String	pref ;
	private String	city ;
	private String	title ;
	private String	link ;
	private String	forecastday ;
	private String	day ;
	private String	forecastdate ;
	private String	publictime ;
	private String	telop ;
	private String	description ;
	private String	imgTitle ;
	private String	imgLink ;
	private String	imgUrl ;
	private String	imgWidth ;
	private String	imgHeight ;
	private String	tempMax ;
	private String	tempMin ;
	private String	copyrightTitle ;
	private String	copyrightLink ;
	private String	copyrightImageTitle ;
	private String	copyrightImageUrl ;
	private String	copyrightImageLink ;
    
    public static final String CELSIUS = "&deg;C";
    
    public String getArea() {
        return area;
    }
    public void setArea(String area) {
        this.area = area;
    }
    public String getCity() {
        return city;
    }
    public void setCity(String city) {
        this.city = city;
    }
    public String getCopyrightImageLink() {
        return copyrightImageLink;
    }
    public void setCopyrightImageLink(String copyrightImageLink) {
        this.copyrightImageLink = copyrightImageLink;
    }
    public String getCopyrightImageTitle() {
        return copyrightImageTitle;
    }
    public void setCopyrightImageTitle(String copyrightImageTitle) {
        this.copyrightImageTitle = copyrightImageTitle;
    }
    public String getCopyrightImageUrl() {
        return copyrightImageUrl;
    }
    public void setCopyrightImageUrl(String copyrightImageUrl) {
        this.copyrightImageUrl = copyrightImageUrl;
    }
    public String getCopyrightLink() {
        return copyrightLink;
    }
    public void setCopyrightLink(String copyrightLink) {
        this.copyrightLink = copyrightLink;
    }
    public String getCopyrightTitle() {
        return copyrightTitle;
    }
    public void setCopyrightTitle(String copyrightTitle) {
        this.copyrightTitle = copyrightTitle;
    }
    public String getDay() {
        return day;
    }
    public void setDay(String day) {
        this.day = day;
    }
    public String getDescription() {
        return description;
    }
    public void setDescription(String description) {
        this.description = description;
    }
    public String getForecastdate() {
        return forecastdate;
    }
    public void setForecastdate(String forecastdate) {
        this.forecastdate = forecastdate;
    }
    public String getForecastday() {
        return forecastday;
    }
    public void setForecastday(String forecastday) {
        this.forecastday = forecastday;
    }
    public String getImgHeight() {
        return imgHeight;
    }
    public void setImgHeight(String imgHeight) {
        this.imgHeight = imgHeight;
    }
    public String getImgLink() {
        return imgLink;
    }
    public void setImgLink(String imgLink) {
        this.imgLink = imgLink;
    }
    public String getImgTitle() {
        return imgTitle;
    }
    public void setImgTitle(String imgTitle) {
        this.imgTitle = imgTitle;
    }
    public String getImgUrl() {
        return imgUrl;
    }
    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }
    public String getImgWidth() {
        return imgWidth;
    }
    public void setImgWidth(String imgWidth) {
        this.imgWidth = imgWidth;
    }
    public String getLink() {
        return link;
    }
    public void setLink(String link) {
        this.link = link;
    }
    public String getPref() {
        return pref;
    }
    public void setPref(String pref) {
        this.pref = pref;
    }
    public String getPublictime() {
        return publictime;
    }
    public void setPublictime(String publictime) {
        this.publictime = publictime;
    }
    public String getTelop() {
        return telop;
    }
    public void setTelop(String telop) {
        this.telop = telop;
    }
    public String getTempMax() {
        return tempMax;
    }
    public void setTempMax(String tempMax) {
        this.tempMax = tempMax;
    }
    public String getTempMin() {
        return tempMin;
    }
    public void setTempMin(String tempMin) {
        this.tempMin = tempMin;
    }
    public String getTitle() {
        return title;
    }
    public void setTitle(String title) {
        this.title = title;
    }
    
    public String getTempMaxOutput() {
        if (this.tempMax == null) {
            return "--";
        } else {
            return this.tempMax + CELSIUS;
        }
    }
    
    public String getTempMinOutput() {
        if (this.tempMin == null) {
            return "--";
        } else {
            return this.tempMin + CELSIUS;
        }
    }
	
}
